#include<evive.h>
#include <Wire.h> 

const int MPU_ADDR = 0x68;                              // I2C address of the MPU-6050. If AD0 pin is set to HIGH, the I2C address will be 0x69.
int accelerometer_x, accelerometer_y, accelerometer_z; // variables for accelerometer raw data
int gyro_x, gyro_y, gyro_z;                           // variables for gyro raw data
int temperature;                                     // variables for temperature data

Servo servo1motor;
Servo servo2motor;

int last_base;
int last_link;

const int servo1pin = 44 ;   // base servo
const int servo2pin = 45 ;  // Servo for link 

int servo1_init = 75;  
int servo2_init = 75;

void setup() {
  // put your setup code here, to run once:

   Serial.begin(9600);
   
   // mpu6050 setup 
  Wire.begin();
  Wire.beginTransmission(MPU_ADDR);       // Begins a transmission to the I2C slave (GY-521 board)
  Wire.write(0x6B);                      // PWR_MGMT_1 register
  Wire.write(0);                        // set to zero (wakes up the MPU-6050)
  Wire.endTransmission(true);

   
    // Servo motor setup 

    servo1motor.attach(servo1pin);
    servo2motor.attach(servo2pin);
 
    servo1motor.write(servo1_init);
    servo2motor.write(servo2_init);

    // tft setup 

    tft_init(INITR_BLACKTAB);
    tft.setRotation(1);
    tft.fillScreen(ST7735_BLACK);
  
    tft.setCursor(25,5);
    tft.setTextSize(2);
    tft.setTextColor(ST7735_WHITE,ST7735_BLACK);
    tft.print("STEMpedia");
  
    tft.setCursor(10,50);
    tft.setTextSize(1);
    tft.setTextColor(ST7735_GREEN,ST7735_BLACK);
    tft.print("ACCELEROMETER CONTROLLED ");
    tft.setCursor(45,60);
    tft.print(" ROBOTIC ARM ");
    

    tft.setTextColor(ST7735_GREEN,ST7735_BLACK);
    tft.setCursor(0,95);
    tft.setTextSize(1.8);
    tft.print("FOR MORE INFORMATION VISIT");
    tft.setCursor(30,110);
    tft.setTextColor(ST7735_WHITE,ST7735_BLACK);
    tft.print("thestempedia.com");

}

void loop()
   {
       // put your main code here, to run repeatedly:

  Wire.beginTransmission(MPU_ADDR);
  Wire.write(0x3B);                        // starting with register 0x3B (ACCEL_XOUT_H) [MPU-6000 and MPU-6050 Register Map and Descriptions Revision 4.2, p.40]
  Wire.endTransmission(false);            // the parameter indicates that the Arduino will send a restart. As a result, the connection is kept active.
  Wire.requestFrom(MPU_ADDR, 7*2, true); // request a total of 7*2=14 registers

  // "Wire.read()<<8 | Wire.read();" means two registers are read and stored in the same variable
  accelerometer_x = Wire.read()<<8 | Wire.read();                  // reading registers: 0x3B (ACCEL_XOUT_H) and 0x3C (ACCEL_XOUT_L)
  accelerometer_y = Wire.read()<<8 | Wire.read();                 // reading registers: 0x3D (ACCEL_YOUT_H) and 0x3E (ACCEL_YOUT_L)
  accelerometer_z = Wire.read()<<8 | Wire.read();                // reading registers: 0x3F (ACCEL_ZOUT_H) and 0x40 (ACCEL_ZOUT_L)
  temperature = Wire.read()<<8 | Wire.read();                   // reading registers: 0x41 (TEMP_OUT_H) and 0x42 (TEMP_OUT_L)
  gyro_x = Wire.read()<<8 | Wire.read();                       // reading registers: 0x43 (GYRO_XOUT_H) and 0x44 (GYRO_XOUT_L)
  gyro_y = Wire.read()<<8 | Wire.read();                      // reading registers: 0x45 (GYRO_YOUT_H) and 0x46 (GYRO_YOUT_L)
  gyro_z = Wire.read()<<8 | Wire.read();                     // reading registers: 0x47 (GYRO_ZOUT_H) and 0x48 (GYRO_ZOUT_L)
  
        
        if(accelerometer_x > 13000)
           {
              if(last_base<161)
                {
                   move_up(last_base);
                }
           }
       accelerometer_x  = -(accelerometer_x);
        
         if(accelerometer_x >13000)
            {
               if(last_base>0)
                 {
                    move_down(last_base);
                 }
            }
         if(accelerometer_y > 13000)
             {
                if(last_link<161)
                   {
                      move_left(last_link);
                   }
             }
        accelerometer_y = -(accelerometer_y);
        
        if(accelerometer_y >13000)
             {
                if(last_link>0)
                   {
                       move_right(last_link);
                   }
             }
         else 
         {
          
         }
 

}

void move_left(unsigned int Position)
    {
      Position++;
      servo2motor.write(Position);
      delay(15);
      Serial.println(last_link);
      last_link = Position;
    }
void move_right(unsigned int Position)
   {
      Position--;
      servo2motor.write(Position);
      delay(15);
      Serial.println(last_link);
      last_link = Position; 
   }
void move_up(unsigned int Position)
   {
      Position++;
      servo1motor.write(Position);
      delay(15);
      Serial.println(last_base);
      last_base = Position;
   }
void move_down(unsigned int Position)
   { 
      Position--;
      servo1motor.write(Position);
      delay(15);
      Serial.println(last_base);
      last_base = Position;
   }

